==> jc-1.4.0.tar.gz: gnu/xml/pipeline/XIncludeFilter__24Scrubber.h <==
// class gnu.xml.pipeline.XIncludeFilter$Scrubber

// class file dependencies
// @dep_class c2c3ed4310a669e3 gnu_xml_pipeline_EventFilter
// @dep_class 4c5ee48c08f83b7 gnu_xml_pipeline_XIncludeFilter__24Scrubber
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_pipeline_EventFilter

#include "gnu/xml/pipeline/EventFilter.h"

#ifndef _JC_gnu_xml_pipeline_XIncludeFilter__24Scrubber_H_
#define _JC_gnu_xml_pipeline_XIncludeFilter__24Scrubber_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_EventFilter$object;
struct _jc_gnu_xml_pipeline_XIncludeFilter$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_xml_sax_Locator$object;

// Typedefs
typedef struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$sub_refs	_jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$sub_refs;
typedef struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$sub_nonrefs	_jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$sub_nonrefs;
typedef struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$refs	_jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$refs;
typedef struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$nonrefs	_jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$nonrefs;
typedef struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object	_jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object;

typedef const struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$vmethods	_jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$vmethods;
typedef const struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$vtable	_jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$vtable;
typedef const struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$vtype	_jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$vtype;

// Constructors
extern void _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$method$_init$2ec51467dd1e8f2d(_jc_env *, struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object *, struct _jc_gnu_xml_pipeline_XIncludeFilter$object *, struct _jc_gnu_xml_pipeline_EventFilter$object *);

// Virtual methods
extern void _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$method$endDTD$409c8a38387cb3cd(_jc_env *, struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object *);
extern void _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$method$endDocument$4903a775f2613143(_jc_env *, struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object *);
extern void _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$method$reject$a57c5b285d00e225(_jc_env *, struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object *, struct _jc_java_lang_String$object *);
extern void _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$method$setDocumentLocator$74bfc0ffd31080e5(_jc_env *, struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object *, struct _jc_object *);
extern void _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$method$skippedEntity$99a8a41bd07f3238(_jc_env *, struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object *, struct _jc_java_lang_String$object *);
extern void _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$method$startDTD$9af8b85061e8c953(_jc_env *, struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
extern void _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$method$startDocument$00c72777de6ab226(_jc_env *, struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$method_info$endDTD$409c8a38387cb3cd;
extern _jc_method _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$method_info$endDocument$4903a775f2613143;
extern _jc_method _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$method_info$reject$a57c5b285d00e225;
extern _jc_method _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$method_info$setDocumentLocator$74bfc0ffd31080e5;
extern _jc_method _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$method_info$skippedEntity$99a8a41bd07f3238;
extern _jc_method _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$method_info$startDTD$9af8b85061e8c953;
extern _jc_method _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$method_info$startDocument$00c72777de6ab226;

// Virtual methods structure
struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$vmethods {
	void	(*endDTD$409c8a38387cb3cd)(_jc_env *, struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object *);
	void	(*endDocument$4903a775f2613143)(_jc_env *, struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object *);
	void	(*reject$a57c5b285d00e225)(_jc_env *, struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object *, struct _jc_java_lang_String$object *);
	void	(*setDocumentLocator$74bfc0ffd31080e5)(_jc_env *, struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object *, struct _jc_object *);
	void	(*skippedEntity$99a8a41bd07f3238)(_jc_env *, struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object *, struct _jc_java_lang_String$object *);
	void	(*startDTD$9af8b85061e8c953)(_jc_env *, struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *);
	void	(*startDocument$00c72777de6ab226)(_jc_env *, struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object *);
};

// Vtable
struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_EventFilter$vmethods	gnu_xml_pipeline_EventFilter;
	_jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$vmethods	gnu_xml_pipeline_XIncludeFilter__24Scrubber;
};

// Vtype
struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$vtype {
	_jc_type			type;
	_jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$sub_refs {
	struct _jc_gnu_xml_pipeline_XIncludeFilter$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$refs {
    _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$sub_refs	gnu_xml_pipeline_XIncludeFilter__24Scrubber;
    _jc_gnu_xml_pipeline_EventFilter$sub_refs	gnu_xml_pipeline_EventFilter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_EventFilter$sub_nonrefs	gnu_xml_pipeline_EventFilter;
    _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$sub_nonrefs	gnu_xml_pipeline_XIncludeFilter__24Scrubber;
};

// Object instance structure
struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object {
	_jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$vtype	*vtype;
	_jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$vtype _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_pipeline_XIncludeFilter__24Scrubber, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$class_object;

#endif	/* _JC_gnu_xml_pipeline_XIncludeFilter__24Scrubber_H_ */

==> jc-1.4.6.tar.gz: gnu/xml/pipeline/XIncludeFilter__24Scrubber.h <==
// class gnu.xml.pipeline.XIncludeFilter$Scrubber

// class file dependencies
// @dep_class c2c3ed4310a669e3 gnu_xml_pipeline_EventFilter
// @dep_class 4c5ee48c08f83b7 gnu_xml_pipeline_XIncludeFilter__24Scrubber
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_pipeline_EventFilter

#include "gnu/xml/pipeline/EventFilter.h"

#ifndef _JC_gnu_xml_pipeline_XIncludeFilter__24Scrubber_H_
#define _JC_gnu_xml_pipeline_XIncludeFilter__24Scrubber_H_

// Forward structure declarations
struct _jc_gnu_xml_pipeline_EventFilter$object;
struct _jc_gnu_xml_pipeline_XIncludeFilter$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_String$object;
struct _jc_org_xml_sax_Locator$object;

// Typedefs
typedef struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$sub_refs	_jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$sub_refs;
typedef struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$sub_nonrefs	_jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$sub_nonrefs;
typedef struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$refs	_jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$refs;
typedef struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$nonrefs	_jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$nonrefs;
typedef struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object	_jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object;

typedef const struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$vmethods	_jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$vmethods;
typedef const struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$vtable	_jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$vtable;
typedef const struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$vtype	_jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$vtype;

// Constructors
extern void _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$method$_init$2ec51467dd1e8f2d(_jc_env *, struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object *, struct _jc_gnu_xml_pipeline_XIncludeFilter$object *, struct _jc_gnu_xml_pipeline_EventFilter$object *) _JC_JCNI_ATTR;

// Virtual methods
extern void _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$method$endDTD$409c8a38387cb3cd(_jc_env *, struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$method$endDocument$4903a775f2613143(_jc_env *, struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$method$reject$a57c5b285d00e225(_jc_env *, struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$method$setDocumentLocator$74bfc0ffd31080e5(_jc_env *, struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$method$skippedEntity$99a8a41bd07f3238(_jc_env *, struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$method$startDTD$9af8b85061e8c953(_jc_env *, struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$method$startDocument$00c72777de6ab226(_jc_env *, struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$method_info$endDTD$409c8a38387cb3cd;
extern _jc_method _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$method_info$endDocument$4903a775f2613143;
extern _jc_method _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$method_info$reject$a57c5b285d00e225;
extern _jc_method _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$method_info$setDocumentLocator$74bfc0ffd31080e5;
extern _jc_method _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$method_info$skippedEntity$99a8a41bd07f3238;
extern _jc_method _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$method_info$startDTD$9af8b85061e8c953;
extern _jc_method _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$method_info$startDocument$00c72777de6ab226;

// Virtual methods structure
struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$vmethods {
	void	(*endDTD$409c8a38387cb3cd)(_jc_env *, struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object *) _JC_JCNI_ATTR;
	void	(*endDocument$4903a775f2613143)(_jc_env *, struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object *) _JC_JCNI_ATTR;
	void	(*reject$a57c5b285d00e225)(_jc_env *, struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*setDocumentLocator$74bfc0ffd31080e5)(_jc_env *, struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object *, struct _jc_object *) _JC_JCNI_ATTR;
	void	(*skippedEntity$99a8a41bd07f3238)(_jc_env *, struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*startDTD$9af8b85061e8c953)(_jc_env *, struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *, struct _jc_java_lang_String$object *) _JC_JCNI_ATTR;
	void	(*startDocument$00c72777de6ab226)(_jc_env *, struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_pipeline_EventFilter$vmethods	gnu_xml_pipeline_EventFilter;
	_jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$vmethods	gnu_xml_pipeline_XIncludeFilter__24Scrubber;
};

// Vtype
struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$vtype {
	_jc_type			type;
	_jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$sub_refs {
	struct _jc_gnu_xml_pipeline_XIncludeFilter$object	*this;
};

// Reference instance fields (object)
struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$refs {
    _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$sub_refs	gnu_xml_pipeline_XIncludeFilter__24Scrubber;
    _jc_gnu_xml_pipeline_EventFilter$sub_refs	gnu_xml_pipeline_EventFilter;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_pipeline_EventFilter$sub_nonrefs	gnu_xml_pipeline_EventFilter;
    _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$sub_nonrefs	gnu_xml_pipeline_XIncludeFilter__24Scrubber;
};

// Object instance structure
struct _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$object {
	_jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$vtype	*vtype;
	_jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$vtype _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_pipeline_XIncludeFilter__24Scrubber, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_pipeline_XIncludeFilter__24Scrubber$class_object;

#endif	/* _JC_gnu_xml_pipeline_XIncludeFilter__24Scrubber_H_ */
